xquery version "3.1";

(:~
 : This module provides the API endpoints for various functions.
 :
 : @author Simon Sendler
 : @version 1.0
 : @since 0.4.1
 :)
module namespace kmg-download="https://mollenhauer-edition.de/ns/kmg-rest";

import module namespace config="https://sade.textgrid.de/ns/config" at "../../config.xqm";
import module namespace selection = "https://mollenhauer-edition.de/ns/conversions/selection" at "../conversions/selection.xqm";
import module namespace json = "https://mollenhauer-edition.de/ns/conversions/json" at "../conversions/json.xqm";
import module namespace bibref="https://mollenhauer-edition.de/ns/conversions/bibref" at "../conversions/bibref.xqm";
import module namespace rest="http://exquery.org/ns/restxq";
import module namespace functx="http://www.functx.com";

declare namespace tei="http://www.tei-c.org/ns/1.0";
declare namespace output ="http://www.w3.org/2010/xslt-xquery-serialization";
declare namespace tg="http://textgrid.info/namespaces/metadata/core/2010";
declare namespace lido="http://www.lido-schema.org";

(:~
 : Provides the full xml of an edition.
 :
 : @param $uri A valig TextGrid-URI without prefix
 : @return The requested XML-document
 :)
declare
  %rest:GET
  %rest:path("/api/download/xml/{$uri}")
  %output:method("xml")
function kmg-download:full-xml($uri as xs:string)
as node()*
{
    let $doc-path := $config:sade-data || $uri || ".xml"
    return
        doc($doc-path)
};

declare
    %rest:GET
    %rest:path("/api/download/plain/{$uri}/{$edition}")
    %output:method("json")
function kmg-download:plai($uri as xs:string, $edition as xs:string)
as xs:string*
{
    let $filename := $uri || ".xml"
    let $plain-text := json:plain-text($config:sade-data, $filename, $edition)("versions")(1)("data")
    return
        $plain-text
};
